@@ -225,7 +225,6 @@ class s2py():
     def followUser(self, username):
         self.headers['referer'] = "https://scratch.mit.edu/users/" + \
             str(username)+"/"
-        print(self.headers)
         return requests.put(
             "https://scratch.mit.edu/site-api/users/followers/"
             + username
@@ -235,14 +234,17 @@ class s2py():
         ).json()
 
     def unfollowUser(self, username):
+        self.headers['referer'] = "https://scratch.mit.edu/users/" + \
+            str(username)+"/"
         return requests.put(
             "https://scratch.mit.edu/site-api/users/followers/"
-            + username
+            + self.username
             + "/remove/?usernames="
-            + self.username,
+            + username,
             headers=self.headers,
         ).json()
 
+
     def toggleCommenting(self):
         self.headers['referer'] = "https://scratch.mit.edu/users/" + \
             str(self.username)
@@ -274,11 +276,6 @@ class s2py():
               str(self.username)+"messages" + "/")
         return requests.get("https://api.scratch.mit.edu/users/"+str(self.username)+"/messages" + "/", headers=self.headers).json()
 
-    def getUserFollowerCount(self, user):
-        response = requests.get(
-            "https://scratchdb.lefty.one/v3/user/info/"+str(user)).json()
-        return response['statistics']['followers']
-
     def getUserStatus(self, user):
         return requests.get("https://api.scratch.mit.edu/users/"+str(user)).json()['profile']['status']
 
